aboutsummaryrefslogtreecommitdiffstats
path: root/dashboard/dashapi/dashapi.go
diff options
context:
space:
mode:
Diffstat (limited to 'dashboard/dashapi/dashapi.go')
-rw-r--r--dashboard/dashapi/dashapi.go5
1 files changed, 3 insertions, 2 deletions
diff --git a/dashboard/dashapi/dashapi.go b/dashboard/dashapi/dashapi.go
index b05f3fbf5..833dd099f 100644
--- a/dashboard/dashapi/dashapi.go
+++ b/dashboard/dashapi/dashapi.go
@@ -172,8 +172,9 @@ const (
type JobDoneFlags int64
const (
- BisectResultMerge JobDoneFlags = 1 << iota // bisected to a merge commit
- BisectResultNoop // commit does not affect resulting kernel binary
+ BisectResultMerge JobDoneFlags = 1 << iota // bisected to a merge commit
+ BisectResultNoop // commit does not affect resulting kernel binary
+ BisectResultRelease // commit is a kernel release
)
func (dash *Dashboard) JobPoll(req *JobPollReq) (*JobPollResp, error) {